@@ -73,7 +73,9 @@ def ligand_breakdown(mol):
 	# this function takes an octahedral 
 	# complex and returns ligands
 	metal_index = mol.findMetal()[0]
-	bondedatoms = mol.getBondedAtomsSmart(metal_index)
+	bondedatoms = mol.getBondedAtomsOct(metal_index,CN=6,debug=False)
+	print('from get oct' + str(bondedatoms))
+	print('***\n')
 	bonded_atom_symbols = [mol.getAtom(i).symbol() for i in bondedatoms]              
 	counter = 0
 	liglist = []
@@ -128,7 +130,7 @@ def ligand_assign(mol,liglist,ligdents,ligcons,loud=False,name=False):
                 valid = False
                 print('bad denticities: ' + str(ligdents)) 
                 print('max denticities: ' + str(min(ligdents))) 
-	if n_ligs > 3:
+	if n_ligs > 3 and min(ligdents)>1:
                 valid = False              
                 print('too many ligs ' + str((n_ligs))) 
 	eq_lig_list = list()
