@@ -174,7 +174,17 @@ class mol3D:
         pmc[1] /= self.natoms
         pmc[2] /= self.natoms
         return pmc
-
+    ## remove all openbabel bond order indo
+    #  @param self The object pointer
+    def cleanBonds(self):
+        obiter = openbabel.OBMolBondIter(self.OBMol)
+        n = self.natoms
+        bonds_to_del =  []
+        for bond in  obiter:
+            these_inds = [bond.GetBeginAtomIdx(),bond.GetEndAtomIdx()]
+            bonds_to_del.append(bond)
+        for i in bonds_to_del:
+            self.OBMol.DeleteBond(i)
     ## Converts OBMol to mol3D
     #
     #  Generally used after openbabel operations, such as when initializing a molecule from a file or FF optimizing it.
@@ -197,7 +207,16 @@ class mol3D:
     #
     #  Required for performing openbabel operations on a molecule, such as FF optimizations.
     #  @param self The object pointer
-    def convert2OBMol(self):
+    #  @param force_clean bool force no bond info retentsion 
+    def convert2OBMol(self,force_clean=False):
+        
+        # get BO matrix if exits:
+        repop  = False
+        
+        if self.OBMol and not force_clean:
+            BO_mat = self.populateBOMatrix()
+            repop = True 
+        
         # write temp xyz
         self.writexyz('tempr.xyz')
 
@@ -206,23 +225,76 @@ class mol3D:
 
         OBMol = openbabel.OBMol()
         obConversion.ReadFile(OBMol,'tempr.xyz')        
-        
+        self.OBMol=  []
         self.OBMol = OBMol
+        
         os.remove('tempr.xyz')
         
+        if repop and not force_clean:
+            self.cleanBonds()
+            for i in range(0,self.natoms):
+                for j in range(0,self.natoms):
+                    if BO_mat[i][j]>0:
+                        self.OBMol.AddBond(i+1,j+1,int(BO_mat[i][j]))
+        
+        
+        
     ## Combines two molecules
     #
     #  Each atom in the second molecule is appended to the first while preserving orders.
     #  @param self The object pointer
     #  @param mol mol3D containing molecule to be added
+    #  @param list of tuples (ind1,ind2,order) bonds to add (optional)
     #  @return mol3D contaning combined molecule
-    def combine(self,mol):
+    #def combine(self,mol):
+    #    cmol = self
+    #    n_one = cmol.natoms
+    #    n_two = mol.natoms
+    #    for atom in mol.atoms:
+    #        cmol.addAtom(atom)
+    #    cmol.graph = []
+    #    return cmol
+
+    def combine(self,mol,bond_to_add=[]):
+    #BondSafe
         cmol = self
+        cmol.convert2OBMol()
+        mol.convert2OBMol()
+        n_one = cmol.natoms
+        n_two = mol.natoms
+        n_tot = n_one + n_two
+        # allocate
+        jointBOMat = np.zeros([n_tot,n_tot])
+        # get individual mats 
+        con_mat_one = cmol.populateBOMatrix()
+        con_mat_two = mol.populateBOMatrix()
+        # combine mats
+        for i in range(0,n_one):
+            for j in range(0,n_one):
+                jointBOMat[i][j] = con_mat_one[i][j]
+        for i in range(0,n_two):
+            for j in range(0,n_two):
+                jointBOMat[i+n_one][j+n_one] = con_mat_two[i][j]
+        # optional add additional bond(s)
+        if bond_to_add:
+            for bond_tuples in bond_to_add:
+                    print('adding bond ' + str(bond_tuples))
+                    jointBOMat[bond_tuples[0],bond_tuples[1]] = bond_tuples[2]
+                    jointBOMat[bond_tuples[1],bond_tuples[0]] = bond_tuples[2]
+        # add mol3Ds
         for atom in mol.atoms:
             cmol.addAtom(atom)
+        cmol.convert2OBMol()
+        # clean all bonds
+        cmol.cleanBonds()
+        # restore bond info
+        for i in range(0,n_tot):
+            for j in range(0,n_tot):
+                if jointBOMat[i][j]>0:
+                    cmol.OBMol.AddBond(i+1,j+1,int(jointBOMat[i][j]))
+        # reset graph
         cmol.graph = []
         return cmol
-
     ## Prints coordinates of all atoms in molecule
     #  @param self The object pointer
     #  @return String containing coordinates
@@ -269,11 +341,15 @@ class mol3D:
         
     ## Create molecular graph (connectivity matrix) from mol3D info
     #  @param self The object pointer
-    def createMolecularGraph(self):
+    #  @oct flag to control  special oct-metal bonds
+    def createMolecularGraph(self,oct=True):
         index_set = range(0,self.natoms)
         A  = np.matrix(np.zeros((self.natoms,self.natoms)))
         for i in index_set:
-            this_bonded_atoms = self.getBondedAtomsOct(i,debug=False)
+            if oct:
+                this_bonded_atoms = self.getBondedAtomsOct(i,debug=False)
+            else:
+                this_bonded_atoms = self.getBondedAtoms(i,debug=False)
             for j in index_set:
                 if j in this_bonded_atoms:
                     A[i,j] = 1
@@ -285,6 +361,8 @@ class mol3D:
     #  @param self The object pointer
     #  @param atomIdx Index of atom to be deleted
     def deleteatom(self,atomIdx):
+        self.convert2OBMol()
+        self.OBMol.DeleteAtom(self.OBMol.GetAtom(atomIdx+1))
         self.mass -= self.getAtom(atomIdx).mass
         self.natoms -= 1
         self.graph = []
@@ -477,6 +555,7 @@ class mol3D:
     #  @param idx Index of desired atom
     #  @return List of coordinates of desired atom
     def getAtomCoords(self,idx):
+        #print(self.printxyz())
         return self.atoms[idx].coords()
 
     ## Gets atoms bonded to a specific atom
@@ -489,17 +568,17 @@ class mol3D:
     #  @param self The object pointer
     #  @param ind Index of reference atom
     #  @return List of indices of bonded atoms
-    def getBondedAtoms(self,ind):
+    def getBondedAtoms(self,ind,debug=False):
         ratom = self.getAtom(ind)
         # calculates adjacent number of atoms
         nats = []
         for i,atom in enumerate(self.atoms):
             d = distance(ratom.coords(),atom.coords())
-            distance_max = 1.30*(atom.rad+ratom.rad) 
+            distance_max = 1.35*(atom.rad+ratom.rad) 
             if atom.symbol() == "C" and not ratom.symbol() == "H":
-                distance_max = min(2.8,distance_max)
+                distance_max = min(2.75,distance_max)
             if ratom.symbol() == "C" and not atom.symbol() == "H":
-                distance_max = min(2.8,distance_max)
+                distance_max = min(2.75,distance_max)
             if ratom.symbol() == "H" and atom.ismetal:
                 ## tight cutoff for metal-H bonds
                 distance_max = 1.1*(atom.rad+ratom.rad) 
@@ -544,7 +623,9 @@ class mol3D:
                     print('metal in  cat ' + str(atom.symbol()) + ' and rat ' +str(ratom.symbol()) )
                 ## one the atoms is a metal!
                 ## use a longer max for metals
-                distance_max = 1.30*(atom.rad+ratom.rad) 
+                distance_max = min(2.75,1.35*(atom.rad+ratom.rad))
+                if debug:
+                    print('maximum bonded distance is ' + str(distance_max) )
                 if d < distance_max and i!=ind:
                     ### trim Hydrogens
                     if atom.symbol() == 'H' or ratom.symbol() == 'H':
@@ -557,6 +638,7 @@ class mol3D:
                         if atom.symbol() == "C":           
                             ## in this case, atom might be intruder C!
                             possible_inds = self.getBondedAtomsnotH(ind) ## bonded to metal
+                            print('poss inds are' + str(possible_inds))
                             if len(possible_inds)>CN:
                                 metal_prox = sorted(possible_inds,key=lambda x: self.getDistToMetal(x,ind))
                                
@@ -614,12 +696,12 @@ class mol3D:
     #
     #  @param self The object pointer
     #  @param ind Index of reference atom
+    #  @param oct Flag to turn on special octahedral complex routines
     #  @return List of indices of bonded atoms
-    def getBondedAtomsSmart(self,ind):
+    def getBondedAtomsSmart(self,ind,oct=True):
         if not len(self.graph):
-            self.createMolecularGraph()
+            self.createMolecularGraph(oct=oct)
         return list(np.nonzero(np.ravel(self.graph[ind]))[0])
-
     ## Gets non-H atoms bonded to a specific atom
     #
     #  Otherwise identical to getBondedAtoms().
@@ -634,13 +716,34 @@ class mol3D:
             d = distance(ratom.coords(),atom.coords())
             distance_max = 1.15*(atom.rad+ratom.rad)
             if atom.ismetal() or ratom.ismetal(): 
-                distance_max = 1.30*(atom.rad+ratom.rad) 
+                distance_max = 1.35*(atom.rad+ratom.rad) 
             else:
                 distance_max = 1.15*(atom.rad+ratom.rad)
             if (d < distance_max and i!=ind and atom.sym!='H'):
                 nats.append(i)
         return nats
 
+    ## Gets H atoms bonded to a specific atom
+    #
+    #  Otherwise identical to getBondedAtoms().
+    #  @param self The object pointer
+    #  @param ind Index of reference atom
+    #  @return List of indices of bonded atoms
+    def getBondedAtomsH(self,ind):
+        ratom = self.getAtom(ind)
+        # calculates adjacent number of atoms
+        nats = []
+        for i,atom in enumerate(self.atoms):
+            d = distance(ratom.coords(),atom.coords())
+            distance_max = 1.15*(atom.rad+ratom.rad)
+            if atom.ismetal() or ratom.ismetal(): 
+                distance_max = 1.35*(atom.rad+ratom.rad) 
+            else:
+                distance_max = 1.15*(atom.rad+ratom.rad)
+            if (d < distance_max and i!=ind and atom.sym=='H'):
+                nats.append(i)
+        return nats
+
     ## Gets atom that is furthest from the molecule COM along a given direction and returns the corresponding distance
     #  @param self The object pointer
     #  @param uP Search direction
@@ -943,7 +1046,19 @@ class mol3D:
                     break
         return overlap
         
-        
+    ## Gets a matrix with bond orders from openbabel
+    #  @param self The object pointer
+    #  @return matrix of bond orders
+    def populateBOMatrix(self):
+        obiter = openbabel.OBMolBondIter(self.OBMol)
+        n = self.natoms
+        molBOMat = np.zeros((n,n))
+        for bond in  obiter:
+            these_inds = [bond.GetBeginAtomIdx(),bond.GetEndAtomIdx()]
+            this_order = bond.GetBondOrder()
+            molBOMat[these_inds[0]-1,these_inds[1]-1]=this_order
+            molBOMat[these_inds[1]-1,these_inds[0]-1]=this_order
+        return(molBOMat)
     ## Prints xyz coordinates to stdout
     # 
     #  To write to file (more common), use writexyz() instead.
@@ -1071,6 +1186,30 @@ class mol3D:
         f=open(fname+'.xyz','w')
         f.write(ss)
         f.close()
+        
+    ## Writes xyz file with atom numbers
+    #
+    #  some codes require this, e.g. packmol/moltemplate.
+    #  @param self The object pointer   
+    #  @param filename Filename  
+    def writenumberedxyz(self,filename):
+        ss = '' # initialize returning string
+        ss += str(self.natoms)+"\n"+time.strftime('%m/%d/%Y %H:%M')+", XYZ structure generated by mol3D Class, "+self.globs.PROGRAM+"\n"
+        unique_types = dict()
+        
+        for atom in self.atoms:
+            this_sym = atom.symbol()
+            if not this_sym in unique_types.keys():
+                unique_types.update({this_sym:1})
+            else:
+                unique_types.update({this_sym:unique_types[this_sym]+1})
+            atom_name = str(atom.symbol())+str(unique_types[this_sym])
+            xyz = atom.coords()
+            ss += "%s \t%f\t%f\t%f\n" % (atom_name,xyz[0],xyz[1],xyz[2])
+        fname = filename.split('.xyz')[0]
+        f=open(fname+'.xyz','w')
+        f.write(ss)
+        f.close()
 
     ## Writes xyz file for 2 molecules separated
     #
